@@ -3,7 +3,7 @@
 __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 
-import os, glob, functools, re
+import os, glob, re
 from calibre import guess_type
 from calibre.customize import (FileTypePlugin, MetadataReaderPlugin,
     MetadataWriterPlugin, PreferencesPlugin, InterfaceActionBase, StoreBase)
@@ -143,14 +143,11 @@ class ComicMetadataReader(MetadataReaderPlugin):
             elif id_.startswith(b'PK'):
                 ftype = 'cbz'
         if ftype == 'cbr':
-            from calibre.utils.unrar import extract_first_alphabetically as extract_first
-            extract_first
+            from calibre.utils.unrar import extract_cover_image
         else:
-            from calibre.libunzip import extract_member
-            extract_first = functools.partial(extract_member,
-                    sort_alphabetically=True)
+            from calibre.libunzip import extract_cover_image
         from calibre.ebooks.metadata import MetaInformation
-        ret = extract_first(stream)
+        ret = extract_cover_image(stream)
         mi = MetaInformation(None, None)
         stream.seek(0)
         if ftype in {'cbr', 'cbz'}:
@@ -295,12 +292,12 @@ class DocXMetadataReader(MetadataReaderPlugin):
 class OPFMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read OPF metadata'
-    file_types  = set(['opf'])
+    file_types  = {'opf'}
     description = _('Read metadata from %s files')%'OPF'
 
     def get_metadata(self, stream, ftype):
-        from calibre.ebooks.metadata.opf2 import OPF
-        return OPF(stream, os.getcwdu()).to_book_metadata()
+        from calibre.ebooks.metadata.opf import get_metadata
+        return get_metadata(stream)[0]
 
 class PDBMetadataReader(MetadataReaderPlugin):
 
@@ -684,10 +681,9 @@ from calibre.devices.sne.driver import SNE
 from calibre.devices.misc import (
     PALMPRE, AVANT, SWEEX, PDNOVEL, GEMEI, VELOCITYMICRO, PDNOVEL_KOBO,
     LUMIREAD, ALURATEK_COLOR, TREKSTOR, EEEREADER, NEXTBOOK, ADAM, MOOVYBOOK,
-    COBY, EX124G, WAYTEQ, WOXTER, POCKETBOOK626, SONYDPTS1)
+    COBY, EX124G, WAYTEQ, WOXTER, POCKETBOOK626, SONYDPTS1, CERVANTES)
 from calibre.devices.folder_device.driver import FOLDER_DEVICE_FOR_CONFIG
 from calibre.devices.kobo.driver import KOBO, KOBOTOUCH
-from calibre.devices.bambook.driver import BAMBOOK
 from calibre.devices.boeye.driver import BOEYE_BEX, BOEYE_BDX
 from calibre.devices.smart_device_app.driver import SMART_DEVICE_APP
 from calibre.devices.mtp.driver import MTP_DEVICE
@@ -742,7 +738,7 @@ plugins += [
     KOBO, KOBOTOUCH,
     AZBOOKA,
     FOLDER_DEVICE_FOR_CONFIG,
-    AVANT,
+    AVANT, CERVANTES,
     MENTOR,
     SWEEX,
     PDNOVEL,
@@ -752,7 +748,6 @@ plugins += [
     PDNOVEL_KOBO,
     LUMIREAD,
     ALURATEK_COLOR,
-    BAMBOOK,
     TREKSTOR,
     EEEREADER,
     NEXTBOOK,
@@ -1035,7 +1030,7 @@ class Columns(PreferencesPlugin):
 class Toolbar(PreferencesPlugin):
     name = 'Toolbar'
     icon = I('wizard.png')
-    gui_name = _('Toolbar')
+    gui_name = _('Toolbars')
     category = 'Interface'
     gui_category = _('Interface')
     category_order = 1
@@ -1260,7 +1255,7 @@ class StoreAmazonKindleStore(StoreBase):
 
     headquarters = 'US'
     formats = ['KINDLE']
-    affiliate = True
+    affiliate = False
 
 class StoreSonyStore(StoreBase):
     name = 'SONY Reader Store'
@@ -1278,65 +1273,77 @@ class StoreSonyAUStore(StoreSonyStore):
     actual_plugin = 'calibre.gui2.store.stores.sony_au_plugin:SonyStore'
     headquarters = 'AU'
 
+class StoreAmazonAUKindleStore(StoreBase):
+    name = 'Amazon AU Kindle'
+    author = u'Kovid Goyal'
+    description = u'Kindle books from Amazon.'
+    actual_plugin = 'calibre.gui2.store.stores.amazon_au_plugin:AmazonKindleStore'
+
+    headquarters = 'AU'
+    formats = ['KINDLE']
+
 class StoreAmazonCAKindleStore(StoreBase):
     name = 'Amazon CA Kindle'
-    author = u'Tomasz Długosz'
+    author = u'Kovid Goyal'
     description = u'Kindle books from Amazon.'
-    actual_plugin = 'calibre.gui2.store.stores.amazon_ca_plugin:AmazonCAKindleStore'
+    actual_plugin = 'calibre.gui2.store.stores.amazon_ca_plugin:AmazonKindleStore'
 
     headquarters = 'CA'
     formats = ['KINDLE']
-    # affiliate = True
+
+class StoreAmazonINKindleStore(StoreBase):
+    name = 'Amazon IN Kindle'
+    author = u'Kovid Goyal'
+    description = u'Kindle books from Amazon.'
+    actual_plugin = 'calibre.gui2.store.stores.amazon_in_plugin:AmazonKindleStore'
+
+    headquarters = 'IN'
+    formats = ['KINDLE']
 
 class StoreAmazonDEKindleStore(StoreBase):
     name = 'Amazon DE Kindle'
-    author = 'Charles Haley'
+    author = 'Kovid Goyal'
     description = u'Kindle Bücher von Amazon.'
-    actual_plugin = 'calibre.gui2.store.stores.amazon_de_plugin:AmazonDEKindleStore'
+    actual_plugin = 'calibre.gui2.store.stores.amazon_de_plugin:AmazonKindleStore'
 
     headquarters = 'DE'
     formats = ['KINDLE']
-    affiliate = True
 
 class StoreAmazonFRKindleStore(StoreBase):
     name = 'Amazon FR Kindle'
-    author = 'Charles Haley'
+    author = 'Kovid Goyal'
     description = u'Tous les ebooks Kindle'
-    actual_plugin = 'calibre.gui2.store.stores.amazon_fr_plugin:AmazonFRKindleStore'
+    actual_plugin = 'calibre.gui2.store.stores.amazon_fr_plugin:AmazonKindleStore'
 
     headquarters = 'FR'
     formats = ['KINDLE']
-    affiliate = True
 
 class StoreAmazonITKindleStore(StoreBase):
     name = 'Amazon IT Kindle'
-    author = 'Charles Haley'
+    author = 'Kovid Goyal'
     description = u'eBook Kindle a prezzi incredibili'
-    actual_plugin = 'calibre.gui2.store.stores.amazon_it_plugin:AmazonITKindleStore'
+    actual_plugin = 'calibre.gui2.store.stores.amazon_it_plugin:AmazonKindleStore'
 
     headquarters = 'IT'
     formats = ['KINDLE']
-    affiliate = True
 
 class StoreAmazonESKindleStore(StoreBase):
     name = 'Amazon ES Kindle'
-    author = 'Charles Haley'
+    author = 'Kovid Goyal'
     description = u'eBook Kindle en España'
-    actual_plugin = 'calibre.gui2.store.stores.amazon_es_plugin:AmazonESKindleStore'
+    actual_plugin = 'calibre.gui2.store.stores.amazon_es_plugin:AmazonKindleStore'
 
     headquarters = 'ES'
     formats = ['KINDLE']
-    affiliate = True
 
 class StoreAmazonUKKindleStore(StoreBase):
     name = 'Amazon UK Kindle'
-    author = 'Charles Haley'
+    author = 'Kovid Goyal'
     description = u'Kindle books from Amazon\'s UK web site. Also, includes French language ebooks.'
-    actual_plugin = 'calibre.gui2.store.stores.amazon_uk_plugin:AmazonUKKindleStore'
+    actual_plugin = 'calibre.gui2.store.stores.amazon_uk_plugin:AmazonKindleStore'
 
     headquarters = 'UK'
     formats = ['KINDLE']
-    affiliate = True
 
 class StoreArchiveOrgStore(StoreBase):
     name = 'Archive.org'
@@ -1742,7 +1749,9 @@ plugins += [
     StoreBubokPublishingStore,
     StoreBubokPortugalStore,
     StoreAmazonKindleStore,
+    StoreAmazonAUKindleStore,
     StoreAmazonCAKindleStore,
+    StoreAmazonINKindleStore,
     StoreAmazonDEKindleStore,
     StoreAmazonESKindleStore,
     StoreAmazonFRKindleStore,
@@ -1827,7 +1836,7 @@ if __name__ == '__main__':
         ret = 0
 
         for x in ('lxml', 'calibre.ebooks.BeautifulSoup', 'uuid',
-            'calibre.utils.terminal', 'calibre.utils.magick', 'PIL', 'Image',
+            'calibre.utils.terminal', 'calibre.utils.img', 'PIL', 'Image',
             'sqlite3', 'mechanize', 'httplib', 'xml', 'inspect', 'urllib',
             'calibre.utils.date', 'calibre.utils.config', 'platform',
             'calibre.utils.zipfile', 'calibre.utils.formatter',
